@@ -1,10 +1,12 @@
 mod add;
+mod config;
 mod get;
 mod init;
 mod list;
 mod remove;
 
 pub use add::add;
+pub use config::config;
 pub use get::get;
 pub use init::init;
 pub use list::list;
