@@ -1,10 +1,10 @@
+use anyhow::{anyhow, Result};
 use colored::*;
-use std::process::exit;
 
 use crate::config;
 
-pub fn remove(shortcut: String) {
-    let mut config: config::Config = config::load_config();
+pub fn remove(shortcut: String) -> Result<i32> {
+    let mut config: config::Config = config::Config::load()?;
     let mut found_shortcut = false;
     let mut index_to_remove: usize = 0;
 
@@ -16,17 +16,15 @@ pub fn remove(shortcut: String) {
     }
 
     if !found_shortcut {
-        println!(
-            "{} {} {}",
-            "Error: Shortcut with call".red(),
-            shortcut.red(),
-            "was not found.".red()
-        );
-        exit(1);
+        return Err(anyhow!(format!(
+            "Shortcut with call {} was not found.",
+            shortcut,
+        )));
     }
 
     config.shortcuts.remove(index_to_remove);
-    config::update_config(config);
+    config.update()?;
     println!("{} {}", "Shortcut removed:".green(), &shortcut);
-    exit(0)
+
+    Ok(0)
 }
